@@ -31,20 +31,21 @@ describe 'horizon::wsgi::apache' do
         is_expected.to contain_file(platforms_params[:httpd_config_file])
         is_expected.to contain_package('horizon').with_ensure('present')
         is_expected.to contain_apache__vhost('horizon_vhost').with(
-          'servername'           => 'some.host.tld',
-          'access_log_file'      => 'horizon_access.log',
-          'error_log_file'       => 'horizon_error.log',
-          'priority'             => '15',
-          'serveraliases'        => ['*'],
-          'docroot'              => '/var/www/',
-          'ssl'                  => 'false',
-          'port'                 => '80',
-          'redirectmatch_status' => 'permanent',
-          'redirectmatch_regexp' => '^/$',
-          'redirectmatch_dest'   => platforms_params[:root_url],
-          'wsgi_script_aliases'  => { platforms_params[:root_url] => '/usr/share/openstack-dashboard/openstack_dashboard/wsgi/django.wsgi' },
-          'wsgi_process_group'   => platforms_params[:wsgi_group],
-          'wsgi_daemon_process'  => platforms_params[:wsgi_group],
+          'servername'             => 'some.host.tld',
+          'access_log_file'        => 'horizon_access.log',
+          'error_log_file'         => 'horizon_error.log',
+          'priority'               => '15',
+          'serveraliases'          => ['*'],
+          'docroot'                => '/var/www/',
+          'ssl'                    => 'false',
+          'port'                   => '80',
+          'redirectmatch_status'   => 'permanent',
+          'redirectmatch_regexp'   => '^/$',
+          'redirectmatch_dest'     => platforms_params[:root_url],
+          'wsgi_script_aliases'    => { platforms_params[:root_url] => '/usr/share/openstack-dashboard/openstack_dashboard/wsgi/django.wsgi' },
+          'wsgi_process_group'     => platforms_params[:wsgi_group],
+          'wsgi_daemon_process'    => platforms_params[:wsgi_group],
+          'wsgi_application_group' => '%{GLOBAL}',
           'wsgi_daemon_process_options' => { 'processes' => params[:wsgi_processes], 'threads' => params[:wsgi_threads], 'user' => platforms_params[:unix_user], 'group' => platforms_params[:unix_group] }
          )
       end
@@ -67,20 +68,21 @@ describe 'horizon::wsgi::apache' do
         is_expected.to contain_file(platforms_params[:httpd_config_file])
         is_expected.to contain_package('horizon').with_ensure('present')
         is_expected.to contain_apache__vhost('horizon_vhost').with(
-          'servername'           => 'some.host.tld',
-          'access_log_file'      => 'horizon_access.log',
-          'error_log_file'       => 'horizon_error.log',
-          'priority'             => params[:priority],
-          'serveraliases'        => ['*'],
-          'docroot'              => '/var/www/',
-          'ssl'                  => 'false',
-          'port'                 => '80',
-          'redirectmatch_status' => 'temp',
-          'redirectmatch_regexp' => '^/$',
-          'redirectmatch_dest'   => platforms_params[:root_url],
-          'wsgi_script_aliases'  => { platforms_params[:root_url] => '/usr/share/openstack-dashboard/openstack_dashboard/wsgi/django.wsgi' },
-          'wsgi_process_group'   => platforms_params[:wsgi_group],
-          'wsgi_daemon_process'  => platforms_params[:wsgi_group],
+          'servername'             => 'some.host.tld',
+          'access_log_file'        => 'horizon_access.log',
+          'error_log_file'         => 'horizon_error.log',
+          'priority'               => params[:priority],
+          'serveraliases'          => ['*'],
+          'docroot'                => '/var/www/',
+          'ssl'                    => 'false',
+          'port'                   => '80',
+          'redirectmatch_status'   => 'temp',
+          'redirectmatch_regexp'   => '^/$',
+          'redirectmatch_dest'     => platforms_params[:root_url],
+          'wsgi_script_aliases'    => { platforms_params[:root_url] => '/usr/share/openstack-dashboard/openstack_dashboard/wsgi/django.wsgi' },
+          'wsgi_process_group'     => platforms_params[:wsgi_group],
+          'wsgi_daemon_process'    => platforms_params[:wsgi_group],
+          'wsgi_application_group' => '%{GLOBAL}',
           'wsgi_daemon_process_options' => { 'processes' => params[:wsgi_processes], 'threads' => params[:wsgi_threads], 'user' => platforms_params[:unix_user], 'group' => platforms_params[:unix_group] }
          )
       end
@@ -118,24 +120,26 @@ describe 'horizon::wsgi::apache' do
           'redirectmatch_dest'     => platforms_params[:root_url],
           'wsgi_process_group'     => 'horizon-ssl',
           'wsgi_daemon_process'    => 'horizon-ssl',
+          'wsgi_application_group' => '%{GLOBAL}',
           'wsgi_script_aliases'  => { platforms_params[:root_url] => '/usr/share/openstack-dashboard/openstack_dashboard/wsgi/django.wsgi' },
         )}
 
         it { is_expected.to contain_apache__vhost('horizon_vhost').with(
-          'servername'           => 'some.host.tld',
-          'access_log_file'      => 'horizon_access.log',
-          'error_log_file'       => 'horizon_error.log',
-          'priority'             => '15',
-          'serveraliases'        => ['*'],
-          'docroot'              => '/var/www/',
-          'ssl'                  => 'false',
-          'port'                 => '80',
-          'redirectmatch_status' => 'permanent',
-          'redirectmatch_regexp' => '(.*)',
-          'redirectmatch_dest'   => 'https://some.host.tld',
-          'wsgi_process_group'   => platforms_params[:wsgi_group],
-          'wsgi_daemon_process'  => platforms_params[:wsgi_group],
-          'wsgi_script_aliases'  => { platforms_params[:root_url] => '/usr/share/openstack-dashboard/openstack_dashboard/wsgi/django.wsgi' },
+          'servername'             => 'some.host.tld',
+          'access_log_file'        => 'horizon_access.log',
+          'error_log_file'         => 'horizon_error.log',
+          'priority'               => '15',
+          'serveraliases'          => ['*'],
+          'docroot'                => '/var/www/',
+          'ssl'                    => 'false',
+          'port'                   => '80',
+          'redirectmatch_status'   => 'permanent',
+          'redirectmatch_regexp'   => '(.*)',
+          'redirectmatch_dest'     => 'https://some.host.tld',
+          'wsgi_process_group'     => platforms_params[:wsgi_group],
+          'wsgi_daemon_process'    => platforms_params[:wsgi_group],
+          'wsgi_application_group' => '%{GLOBAL}',
+          'wsgi_script_aliases'    => { platforms_params[:root_url] => '/usr/share/openstack-dashboard/openstack_dashboard/wsgi/django.wsgi' },
         )}
       end
 
